package servlet;

import things.Resource;
import things.Things;

import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.time.format.ResolverStyle;
import java.util.Map;

@WebServlet(name = "Things", urlPatterns = {"/things", "/things/*"})
public class ThingsServlet extends HttpServlet {
    private final Things things = new Things();

    public ThingsServlet() {
        super();
        things.addSampleResources();
    }

    @Override
    protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        String uri = req.getRequestURI();

        resp.setContentType("application/json");
        if(things.getResourceByURI(uri)==null){
            resp.sendError(404);
            return;
        }

        resp.getWriter().print(things.getResourceByURI(uri).getJSON());

    }

    @Override
    protected void doPost(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        String uri = req.getRequestURI();
        Map<String, String[]> params = req.getParameterMap();
        Resource.Type type = Resource.Type.valueOf(params.get("type")[0]);
        String name = params.get("name")[0];

        if(things.getResourceByURI(uri)==null) {
            resp.sendError(404);
            return;
        }

        if(type.equals(Resource.Type.THING)) {
            things.addThingWithName(name);
        } else {
            things.addChildToResourceWithURI(uri, name, type);
        }

    }

    @Override
    protected void doDelete(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        String uri = req.getRequestURI();
        if(things.getResourceByURI(uri)==null) {
            resp.sendError(404);
            return;
        }
        things.removeResourceByURI(uri);
    }
}
